@@ -14,7 +14,6 @@
 
 #ifndef COMPUTERESIDUAL_HPP
 #define COMPUTERESIDUAL_HPP
-#include "Geometry.hpp"
-int ComputeResidual(const local_int_t n, const double * const v1,
-    const double * const v2, double * const residual);
+#include "Vector.hpp"
+int ComputeResidual(const local_int_t n, const Vector & v1, const Vector & v2, double & residual);
 #endif // COMPUTERESIDUAL_HPP
