@@ -14,8 +14,7 @@
 
 #ifndef COMPUTEWAXPBY_REF_HPP
 #define COMPUTEWAXPBY_REF_HPP
-#include "Geometry.hpp"
-int ComputeWAXPBY_ref(const local_int_t n, const double alpha, const double * const x,
-    const double beta, const double * const y,
-    double * const w);
+#include "Vector.hpp"
+int ComputeWAXPBY_ref(const local_int_t n, const double alpha, const Vector & x,
+    const double beta, const Vector & y, Vector & w);
 #endif // COMPUTEWAXPBY_REF_HPP
