@@ -15,5 +15,5 @@
 #ifndef GENERATEGEOMETRY_HPP
 #define GENERATEGEOMETRY_HPP
 #include "Geometry.hpp"
-void GenerateGeometry(int size, int rank, int numThreads, int nx, int ny, int nz, Geometry & geom);
+void GenerateGeometry(int size, int rank, int numThreads, int nx, int ny, int nz, Geometry * geom);
 #endif // GENERATEGEOMETRY_HPP
