@@ -14,13 +14,12 @@
 
 #ifndef REPORTRESULTS_HPP
 #define REPORTRESULTS_HPP
-#include "Geometry.hpp"
 #include "SparseMatrix.hpp"
 #include "TestCG.hpp"
 #include "TestSymmetry.hpp"
 #include "TestNorms.hpp"
 
-void ReportResults(const Geometry & geom, const SparseMatrix & A, int numberOfCgSets, int niters, double times[],
-    TestCGData * testcg_data, TestSymmetryData * testsymmetry_data, TestNormsData * testnorms_data, int global_failure);
+void ReportResults(const SparseMatrix & A, int numberOfMgLevels, int numberOfCgSets, int refMaxIters, int niters, double times[],
+    const TestCGData & testcg_data, const TestSymmetryData & testsymmetry_data, const TestNormsData & testnorms_data, int global_failure);
 
 #endif // REPORTRESULTS_HPP
