@@ -23,16 +23,15 @@
 
 #include "hpcg.hpp"
 #include "SparseMatrix.hpp"
-#include "Geometry.hpp"
 #include "CGData.hpp"
 
 struct TestSymmetryData_STRUCT {
   double depsym_spmv;  //!< departure from symmetry for the SPMV kernel
-  double depsym_symgs; //!< departure from symmetry for the SYMGS kernel
+  double depsym_mg; //!< departure from symmetry for the SYMGS kernel
   int    count_fail;   //!< number of failures in the symmetry tests
 };
 typedef struct TestSymmetryData_STRUCT TestSymmetryData;
 
-extern int TestSymmetry(Geometry & geom, SparseMatrix & A, double * const b, double * const xexact, TestSymmetryData * testsymmetry_data);
+extern int TestSymmetry(SparseMatrix & A, Vector & b, Vector & xexact, TestSymmetryData & testsymmetry_data);
 
 #endif  // TESTSYMMETRY_HPP
